-- ************************************ Cash Register ************************************ --
CashRegister = deriveLuaClass("CashRegister", "Object")

function CashRegister:init(desc)
	CashRegister.superInit(self, desc)
	self.clickable = true
	self.useLargeClickArea = true
end

function CashRegister:onLevelInitialized()
	CashRegister.super.onLevelInitialized(self)

	self.counters = self.counters or {}
	for i=1,10 do
		local counter = self["counter"..i]
		if (counter) then
			counter = level:getObject(counter)
		end
		if (counter) then
			table.push_back(self.counters, counter)
		end
	end
end

function CashRegister:getCounters()
	if (table.empty(self.counters)) then
		return level.counters
	end
	return self.counters
end

function CashRegister:onClick()
	CashRegister.super.onClick(self)
	self:playSample("money_cash_register_customer")
	return true
end

function CashRegister:onWorkStart(task)
	CashRegister.super.onWorkStart(self, task)
	local counters = self:getCounters()
	for _,v in ipairs(counters) do
		local characters = v.queue.characters
		for _,c in ipairs(characters) do
			if (c.group.state == "Paying") then
				hints:successfulSequence("checkout customers")
				return true
			end
		end
	end
	return false
end

function CashRegister:onWorkFinish(task)
	CashRegister.super.onWorkFinish(self, task)

	level:onCashRegisterStart(self)

	local payDelay = 300

	local doSound = false
	local counters = self:getCounters()
	local customerGroups = {}
	for _,v in ipairs(counters) do
		v:setBagsInactive()

		local characters = v.queue.characters
		for idx,c in ipairs(characters) do
			if (c.group.state == "Paying") then
				local delay = (idx-1) * payDelay
				--if (level.onCustomerGroupPay) then
				--	level:onCustomerGroupPay(c, delay, self)
				--end
				c.group:handleCustomerPay(delay)
				table.push_back(customerGroups, c.group)
			end
		end
		doSound = true
	end

	local comboScore = 0
	if (#customerGroups > 1) then
		comboScore = self:calcValue("comboCheckout"..math.min(4, #customerGroups));

		if (#customerGroups >= 3) then
			if (level.BM_incCombo3Person) then
				level:BM_incCombo3Person()
			end
			if (player.gameStats.incComboCheckoutChain) then
				player.gameStats:incComboCheckoutChain()
			end
		else
			if (player.gameStats.resetComboCheckoutChain) then
				player.gameStats:resetComboCheckoutChain()
			end
			if (#customerGroups == 2) then
				if (level.BM_incCombo2Person) then
					level:BM_incCombo2Person()
				end
			end
		end
	end

	if (doSound) then
		self:playSample("money_cash_register_end")
		self:animate({{startFrame=0, frameTime=80}, {frame=0}})
	end

	level:onCashRegisterEnd(self, customerGroups, comboScore)
end
